import com.badlogic.gdx.physics.box2d.Body;
import com.badlogic.gdx.physics.box2d.BodyDef;
import com.badlogic.gdx.physics.box2d.BodyDef.BodyType;
import com.badlogic.gdx.physics.box2d.CircleShape;
import com.badlogic.gdx.physics.box2d.Fixture;
import com.badlogic.gdx.physics.box2d.FixtureDef;
import com.badlogic.gdx.physics.box2d.PolygonShape;
import com.badlogic.gdx.physics.box2d.World;

public class Box {
	int x, y;
	int w, h;
	Body body;
	BodyDef bodyDef;
	FixtureDef fixtureDef;
	Fixture fixture;
	
	Box(int x, int y, int w, int h, World boxWorld, BodyType bt, boolean square) {
		this.x = x;
		this.y = y;
		this.w = w;
		this.h = h;
		// First we create a body definition
		bodyDef = new BodyDef();
		// We set our body to dynamic, for something like ground which doesn't
		// move we would set it to StaticBody
		bodyDef.type = bt;
		// Set our body's starting position in the world
		bodyDef.position.set(x, y);
		// Create our body in the world using our body definition
		body = boxWorld.createBody(bodyDef);
		// Create a fixture definition to apply our shape to
		fixtureDef = new FixtureDef();
		fixtureDef.density = 0.5f;
		fixtureDef.friction = 0.4f;
		fixtureDef.restitution = 0.6f; // Make it bounce a little bit
		if(square){
			PolygonShape ps = new PolygonShape();
			ps.setAsBox(w/2, h/2);			
			fixtureDef.shape = ps;
		}else{			
			CircleShape circle = new CircleShape();
			circle.setRadius(w);
			fixtureDef.shape = circle;
		}
		// Create our fixture and attach it to the body
		fixture = body.createFixture(fixtureDef);
	}
}
